@@ -1,4 +1,4 @@
-#!C:\bld\peewee_1508656432106\_b_env\python.exe
+#!C:\bld\peewee_1522298518513\_b_env\python.exe
 
 import datetime
 import sys
@@ -92,7 +92,7 @@ def print_models(introspector, tables=None, preserve_order=False):
 
         print_('')
         print_('    class Meta:')
-        print_('        db_table = \'%s\'' % table)
+        print_('        table_name = \'%s\'' % table)
         multi_column_indexes = database.multi_column_indexes(table)
         if multi_column_indexes:
             print_('        indexes = (')
